/**
 * @description 获取当前市州配置
 * @return
 *     cityName: 'name', // 中文名称
 *     cityCode: 'code', // 6位区号
 *     cityAbbr: 'abbr', // 简写
 *     recordNumber: 'recordNumber', // 备案号
 *     locationCenter: [lat,lng], // 地图中心点
 *     loginBg: 'loginBg', // 登录背景
 *     isShowLogo: true, // 是否显示左上角logo
 */
export const getCurrentCityConfig = () => {
    switch (import.meta.env.VITE_CURRENT_CITY) {
        case 'yibin':
            return {
                cityName: '宜宾市', // 中文名称
                cityCode: '511500', // 6位区号
                cityAbbr: '宜宾', // 简写
                recordNumber: '蜀ICP备19035032号-36', // 备案号
                locationCenter: [104.643, 28.751694], // 地图中心点
                loginBg: 'yibin/login_bg.png', // 登录背景
                isShowLogo: true, // 是否显示左上角logo
                favicon: 'yibin/favicon.ico',
            };
        case 'zigong':
            return {
                cityName: '自贡市',
                cityCode: '510300',
                cityAbbr: 'zg',
                recordNumber: '蜀ICP备2024053169号-1',
                locationCenter: [104.778001, 29.339399],
                // loginBg: 'zigong/login_bg.png',
                loginBg: 'login/login_bg.png',
                isShowLogo: false,
                favicon: 'zigong/favicon.ico',
            };
        default:
            return {
                cityName: '宜宾市', // 中文名称
                cityCode: '511500', // 6位区号
                cityAbbr: '宜宾', // 简写
                recordNumber: '蜀ICP备19035032号-36', // 备案号
                locationCenter: [104.643, 28.751694], // 地图中心点
                loginBg: 'yibin/login_bg.png', // 登录背景
                isShowLogo: true, // 是否显示左上角logo
                favicon: 'yibin/favicon.ico',
            };
    }
};
